@@ -5,9 +5,9 @@ module Tmuxinator
 
     class << self
       def root
-        root_dir = File.expand_path("~/.tmuxinator")
-        Dir.mkdir("#{ENV['HOME']}/.tmuxinator") unless File.directory?(root_dir)
-        "#{ENV['HOME']}/.tmuxinator"
+        root_dir = File.expand_path("#{ENV['HOME']}/.tmuxinator")
+        Dir.mkdir(root_dir) unless File.directory?(root_dir)
+        root_dir
       end
 
       def sample
@@ -43,7 +43,7 @@ module Tmuxinator
       end
 
       def exists?(name)
-        File.exists?(project(name))
+        File.exist?(project(name))
       end
 
       def project_in_root(name)
@@ -56,7 +56,7 @@ module Tmuxinator
       end
 
       def project_in_local
-        [LOCAL_DEFAULT].detect { |f| File.exists?(f) }
+        [LOCAL_DEFAULT].detect { |f| File.exist?(f) }
       end
 
       def default_project(name)
