@@ -20,12 +20,13 @@ describe Tmuxinator::Cli do
   describe "#completions" do
     before do
       ARGV.replace(["completions", "start"])
-      allow(Tmuxinator::Config).to receive_messages(configs: ["test.yml"])
+      allow(Tmuxinator::Config).to receive_messages(configs: ["test.yml",
+                                                              "foo.yml"])
     end
 
     it "gets completions" do
       out, _err = capture_io { cli.start }
-      expect(out).to include("test.yml")
+      expect(out).to include("test.yml\nfoo.yml")
     end
   end
 
@@ -39,8 +40,10 @@ describe Tmuxinator::Cli do
       expected = %w(commands
                     completions
                     new
+                    edit
                     open
                     start
+                    stop
                     local
                     debug
                     copy
@@ -98,6 +101,26 @@ describe Tmuxinator::Cli do
     end
   end
 
+  describe "#stop" do
+    before do
+      ARGV.replace(["stop", "foo"])
+      allow(Tmuxinator::Config).to receive_messages(validate: project)
+      allow(Tmuxinator::Config).to receive_messages(version: 1.9)
+      allow(Kernel).to receive(:exec)
+    end
+
+    context "with project name" do
+      let(:project) { FactoryGirl.build(:project) }
+
+      it "stop the project" do
+        expect(Kernel).to receive(:exec)
+        out, err = capture_io { cli.start }
+        expect(err).to eq ""
+        expect(out).to eq ""
+      end
+    end
+  end
+
   describe "#local" do
     shared_examples_for :local_project do
       before do
@@ -149,6 +172,41 @@ describe Tmuxinator::Cli do
     end
   end
 
+  describe "#edit" do
+    let(:file) { StringIO.new }
+    let(:name) { "test" }
+    let(:path) { Tmuxinator::Config.default_project(name) }
+
+    context "when the project file _does_ already exist" do
+      let(:extra) { "  - extra: echo 'foobar'" }
+
+      before do
+        # make sure that no project file exists initially
+        FileUtils.remove_file(path) if File.exist?(path)
+        expect(File).not_to exist(path)
+
+        # now generate a project file
+        expect(Tmuxinator::Cli.new.generate_project_file(name, path)).to eq path
+        expect(File).to exist path
+
+        # add some content to the project file
+        File.open(path, "w") do |f|
+          f.write(extra)
+          f.flush
+        end
+        expect(File.read(path)).to match %r{#{extra}}
+
+        # get ready to run `tmuxinator edit #{name}`
+        ARGV.replace ["edit", name]
+      end
+
+      it "should _not_ generate a new project file" do
+        capture_io { cli.start }
+        expect(File.read(path)).to match %r{#{extra}}
+      end
+    end
+  end
+
   describe "#new" do
     let(:file) { StringIO.new }
     let(:name) { "test" }
@@ -164,7 +222,7 @@ describe Tmuxinator::Cli do
 
       context "existing project doesn't exist" do
         before do
-          expect(Tmuxinator::Config).to receive_messages(exists?: false)
+          expect(File).to receive_messages(exist?: false)
         end
 
         it "creates a new tmuxinator project file" do
@@ -174,14 +232,15 @@ describe Tmuxinator::Cli do
       end
 
       context "files exists" do
-        let(:command) { "#{ENV['HOME']}\/\.tmuxinator\/#{name}\.yml" }
+        let(:root_path) { "#{ENV['HOME']}\/\.tmuxinator\/#{name}\.yml" }
 
         before do
-          expect(Tmuxinator::Config).to receive_messages(exists?: true)
+          allow(File).to receive(:exist?).with(anything).and_return(false)
+          expect(File).to receive(:exist?).with(root_path).and_return(true)
         end
 
         it "just opens the file" do
-          expect(Kernel).to receive(:system).with(%r{#{command}})
+          expect(Kernel).to receive(:system).with(%r{#{root_path}})
           capture_io { cli.start }
         end
       end
@@ -194,7 +253,7 @@ describe Tmuxinator::Cli do
 
       context "existing project doesn't exist" do
         before do
-          expect(Tmuxinator::Config).to receive(:exists?).at_least(:once) do
+          allow(File).to receive(:exist?).at_least(:once) do
             false
           end
         end
@@ -208,7 +267,7 @@ describe Tmuxinator::Cli do
       context "files exists" do
         let(:path) { Tmuxinator::Config::LOCAL_DEFAULT }
         before do
-          expect(Tmuxinator::Config).to receive(:exists?).with(path) { true }
+          expect(File).to receive(:exist?).with(path) { true }
         end
 
         it "just opens the file" do
@@ -288,30 +347,88 @@ describe Tmuxinator::Cli do
   end
 
   describe "#delete" do
-    before do
-      ARGV.replace(["delete", "foo"])
-      allow(Thor::LineEditor).to receive_messages(readline: "y")
-    end
-
-    context "project exists" do
+    context "with a single argument" do
       before do
-        allow(Tmuxinator::Config).to receive(:exists?) { true }
-      end
-
-      it "deletes the project" do
-        expect(FileUtils).to receive(:rm)
-        capture_io { cli.start }
-      end
-    end
-
-    context "project doesn't exist" do
-      before do
-        allow(Tmuxinator::Config).to receive(:exists?) { false }
+        ARGV.replace(["delete", "foo"])
         allow(Thor::LineEditor).to receive_messages(readline: "y")
       end
 
-      it "exits with error message" do
-        expect { capture_io { cli.start } }.to raise_error SystemExit
+      context "project exists" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?) { true }
+        end
+
+        it "deletes the project" do
+          expect(FileUtils).to receive(:rm)
+          capture_io { cli.start }
+        end
+      end
+
+      context "local project exists" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?) { true }
+          expect(Tmuxinator::Config).to receive(:project) { "local" }
+        end
+
+        it "deletes the local project" do
+          expect(FileUtils).to receive(:rm).with("local")
+          capture_io { cli.start }
+        end
+      end
+
+      context "project doesn't exist" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?) { false }
+        end
+
+        it "outputs an error message" do
+          expect(capture_io { cli.start }[0]).to match(/foo does not exist!/)
+        end
+      end
+    end
+
+    context "with multiple arguments" do
+      before do
+        ARGV.replace(["delete", "foo", "bar"])
+        allow(Thor::LineEditor).to receive_messages(readline: "y")
+      end
+
+      context "all projects exist" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?).and_return(true)
+        end
+
+        it "deletes the projects" do
+          expect(FileUtils).to receive(:rm).exactly(2).times
+          capture_io { cli.start }
+        end
+      end
+
+      context "only one project exists" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?).with("foo") { true }
+          allow(Tmuxinator::Config).to receive(:exists?).with("bar") { false }
+        end
+
+        it "deletes one project" do
+          expect(FileUtils).to receive(:rm)
+          capture_io { cli.start }
+        end
+
+        it "outputs an error message" do
+          expect(capture_io { cli.start }[0]).to match(/bar does not exist!/)
+        end
+      end
+
+      context "all projects do not exist" do
+        before do
+          allow(Tmuxinator::Config).to receive(:exists?).and_return(false)
+        end
+
+        it "outputs multiple error messages" do
+          expect(capture_io { cli.start }[0]).
+            to match(/foo does not exist!\nbar does not exist!/)
+        end
       end
     end
   end
@@ -368,6 +485,69 @@ describe Tmuxinator::Cli do
     end
   end
 
+  describe "#find_project_file" do
+    let(:name) { "foobar" }
+    let(:path) { Tmuxinator::Config.default_project(name) }
+
+    after(:each) do
+      FileUtils.remove_file(path) if File.exist?(path)
+    end
+
+    context "when the project file does not already exist" do
+      before do
+        expect(File).not_to exist(path), "expected file at #{path} not to exist"
+      end
+
+      it "should generate a project file" do
+        new_path = Tmuxinator::Cli.new.find_project_file(name, false)
+        expect(new_path).to eq path
+        expect(File).to exist new_path
+      end
+    end
+
+    context "when the project file _does_ already exist" do
+      let(:extra) { "  - extra: echo 'foobar'" }
+
+      before do
+        expect(File).not_to exist(path), "expected file at #{path} not to exist"
+        expect(Tmuxinator::Cli.new.generate_project_file(name, path)).to eq path
+        expect(File).to exist path
+
+        File.open(path, "w") do |f|
+          f.write(extra)
+          f.flush
+        end
+        expect(File.read(path)).to match %r{#{extra}}
+      end
+
+      it "should _not_ generate a new project file" do
+        new_path = Tmuxinator::Cli.new.find_project_file(name, false)
+        expect(new_path).to eq path
+        expect(File).to exist new_path
+        expect(File.read(new_path)).to match %r{#{extra}}
+      end
+    end
+  end
+
+  describe "#generate_project_file" do
+    let(:name) { "foobar" }
+    let(:path) { Tmuxinator::Config.default_project(name) }
+
+    before do
+      expect(File).not_to exist(path), "expected file at #{path} not to exist"
+    end
+
+    after(:each) do
+      FileUtils.remove_file(path) if File.exist?(path)
+    end
+
+    it "should always generate a project file" do
+      new_path = Tmuxinator::Cli.new.generate_project_file(name, path)
+      expect(new_path).to eq path
+      expect(File).to exist new_path
+    end
+  end
+
   describe "#create_project" do
     shared_examples_for :a_proper_project do
       it "should create a valid project" do
